==> gasrunparts-0.7.tar.gz: gasrunparts-0.7/src/runpart.c <==
/* 
 *  runpart.c 
 *        contains some functions to run example parts into main execute module  
 *   
 *  Copyright (C) 2015  Andrey Y. Rzhavskov  <mailto:rjaan@yandex.ru>
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Affero General Public License as
 *  published by the Free Software Foundation, either version 3 of the
 *  License, or (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Affero General Public License for more details.
 * 
 *  You should have received a copy of the GNU Affero General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 #include "runpart.h"

 #include <alloca.h>
 #include <stdarg.h>
 #include <stdio.h> 
 #include <stdlib.h>
 #include <limits.h>
 #include <unistd.h>
 
 #include <sys/types.h>

/*
 *  runpart_exec()
 *     run an example parts in main execute module
 *  
 *  On success, it will return a value of an execute part at function output. 
 * Otherwise, this value to be -1..            
 */

int runpart_exec ( const char *fmt, ... ) 
{
   va_list      ap;
   int          status;
   uid_t        uid = getuid();
   char       *execmd_buf = alloca(PATH_MAX);
 
   if ( !(fmt != NULL) )  return -1;   
   va_start ( ap, fmt );
   vsnprintf(execmd_buf, PATH_MAX, fmt, ap);
   va_end (ap);

   setenv("SHELL","/bin/bash",1); /* WEXITSTATUS(status) could be not executed 
                                     when a shell to be /bin/sh */
   status = system(execmd_buf);   
   if( status != -1 )    {
     return WEXITSTATUS(status);
   } 
   return -1;
}

#include <errno.h>
#include <string.h>

char path_buf[PATH_MAX]; 

/*
 *  runpart_pwd()
 *     
 *      returns current working directory as a pointer at buffer path_buf. In case      
 * failure, it's returned null-pointer (NULL).
 *  On success, it will return a value of an execute part at function output. 
 * Otherwise, this value to be -1.            
 */
void* runpart_pwd ( void )
{    
   char *ptr = path_buf;
   if ( getcwd( path_buf, PATH_MAX) == NULL ) {
#ifdef __ERRNO_PRINT__
	fprintf ( stderr, "%s(): getcwd(): %s\n", __FUNCTION__, strerror(errno) );
#endif /*__ERRNO_PRINT__*/
      return NULL;  
   }
   return ptr;      
}
 
/*eof*/

==> gasrunparts-0.15.tar.gz: gasrunparts-0.15/src/runpart.c <==
/* 
 *  runpart.c 
 *        contains some functions to run example parts into main execute module  
 *   
 *  Copyright (C) 2015  Andrey Y. Rzhavskov  <mailto:rjaan@yandex.ru>
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Affero General Public License as
 *  published by the Free Software Foundation, either version 3 of the
 *  License, or (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Affero General Public License for more details.
 * 
 *  You should have received a copy of the GNU Affero General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 #include "runpart.h"

 #include <alloca.h>
 #include <stdarg.h>
 #include <stdio.h> 
 #include <stdlib.h>
 #include <limits.h>
 #include <unistd.h>
 
 #include <sys/types.h>

/*
 *  runpart_exec()
 *     run an example parts in main execute module
 *  
 *  On success, it will return a value of an execute part at function output. 
 * Otherwise, this value to be -1..            
 */

int runpart_exec ( const char *fmt, ... ) 
{
   va_list      ap;
   int          status;
   uid_t        uid = getuid();
   char       *execmd_buf = alloca(PATH_MAX);
 
   if ( !(fmt != NULL) )  return -1;   
   va_start ( ap, fmt );
   vsnprintf(execmd_buf, PATH_MAX, fmt, ap);
   va_end (ap);

   setenv("SHELL","/bin/bash",1); /* WEXITSTATUS(status) could be not executed 
                                     when a shell to be /bin/sh */
   status = system(execmd_buf);   
   if( status != -1 )    {
     return WEXITSTATUS(status);
   } 
   return -1;
}

#include <errno.h>
#include <string.h>

char path_buf[PATH_MAX]; 

/*
 *  runpart_pwd()
 *     
 *      returns current working directory as a pointer at buffer path_buf. In case      
 * failure, it's returned null-pointer (NULL).
 *  On success, it will return a value of an execute part at function output. 
 * Otherwise, this value to be -1.            
 */
char* runpart_pwd ( void )
{    
   char *ptr = (char *)path_buf;
   if ( getcwd( path_buf, PATH_MAX) == NULL ) {
#ifdef __ERRNO_PRINT__
	fprintf ( stderr, "%s(): getcwd(): %s\n", __FUNCTION__, strerror(errno) );
#endif /*__ERRNO_PRINT__*/
      return NULL;  
   }
   return ptr;      
}
 
/*eof*/
